@@ -1,10 +1,11 @@
 require 'spec_helper'
 
 describe 'keystone::db::postgresql' do
-
-  shared_examples_for 'keystone::db::postgresql' do
+  shared_examples 'keystone::db::postgresql' do
     let :req_params do
-      { :password => 'pw' }
+      {
+        :password => 'pw',
+      }
     end
 
     let :pre_condition do
@@ -25,18 +26,17 @@ describe 'keystone::db::postgresql' do
   end
 
   on_supported_os({
-    :supported_os   => OSDefaults.get_supported_os
+    :supported_os => OSDefaults.get_supported_os
   }).each do |os,facts|
     context "on #{os}" do
       let (:facts) do
         facts.merge(OSDefaults.get_facts({
-          :os_workers_keystone => 8,
-          :concat_basedir      => '/var/lib/puppet/concat'
+          :os_workers     => 8,
+          :concat_basedir => '/var/lib/puppet/concat'
         }))
       end
 
-      it_configures 'keystone::db::postgresql'
+      it_behaves_like 'keystone::db::postgresql'
     end
   end
-
 end
